balafon
===============================================


Overview
------------------------------------

balafon moto is Organize > Target > Communicate. It helps you to work with your contacts in your day-to-day work


License
=======

CeCCIL 2.1. see license.txt
